Documentation
¶
Index ¶
Constants ¶
const ( CniErrHealthzGet uint = 100 CniErrUnhealthy = iota )
CNI error codes (error codes 100+ are allowed for plugin use)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Args ¶
type Args struct{}
Args contains arbitrary information a scheduler can pass to the cni plugin
type ArgsSpec ¶
type ArgsSpec struct {
cniTypes.CommonArgs
K8S_POD_NAME cniTypes.UnmarshallableString
K8S_POD_NAMESPACE cniTypes.UnmarshallableString
K8S_POD_UID cniTypes.UnmarshallableString
}
ArgsSpec is the specification of additional arguments of the CNI ADD call
type NetConf ¶
type NetConf struct {
cniTypes.NetConf
MTU int `json:"mtu"`
Args Args `json:"args"`
EnableRouteMTU bool `json:"enable-route-mtu"`
ENI eniTypes.ENISpec `json:"eni,omitempty"`
Azure azureTypes.AzureSpec `json:"azure,omitempty"`
IPAM IPAM `json:"ipam,omitempty"` // Shadows the JSON field "ipam" in cniTypes.NetConf.
AlibabaCloud alibabaCloudTypes.Spec `json:"alibaba-cloud,omitempty"`
EnableDebug bool `json:"enable-debug"`
LogFormat string `json:"log-format"`
LogFile string `json:"log-file"`
ChainingMode string `json:"chaining-mode"`
}
NetConf is the Cilium specific CNI network configuration
func LoadNetConf ¶
LoadNetConf unmarshals a Cilium network configuration from JSON and returns a NetConf together with the CNI version
func ReadNetConf ¶
ReadNetConf reads a CNI configuration file and returns the corresponding NetConf structure
type NetConfList ¶
type NetConfList struct {
Plugins []*NetConf `json:"plugins,omitempty"`
}
NetConfList is a CNI chaining configuration
Click to show internal directories.
Click to hide internal directories.